<?php

namespace Drupal\twitter_sync\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\node\Entity\Node;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'TwitterBlock' block.
 *
 * @Block(
 *  id = "twitter_sync_block",
 *  admin_label = @Translation("Twitter Sync block"),
 * )
 */
class TwitterBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * A config service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private $config;

  /**
   * {@inheritdoc}
   */
  public static function create (ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition){
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
  }

  /**
   * Constructor of block.
   *
   * @param array $configuration
   *   Configurations.
   * @param string $plugin_id
   *   Plugin id.
   * @param mixed $plugin_definition
   *   Plugin definition.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config
   *   Config service.
   *
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->config = $config;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {

    $query = \Drupal::entityQuery('node')
      ->condition('type', 'twitter_sync') //content type
      ->pager(3); //specify results to return
    $nids = $query->execute();

    $tweets = [];
    foreach ($nids as $nid) {
      $node = Node::load($nid);
      $tweets[] = $node->field_twitter_sync_status_id->value;
      $screen_name = $node->field_twitter_sync_screen_name->value;
    }

    return [
      '#theme' => 'tweets',
      '#tweets_ids' => $tweets,
      '#screen_name' => $screen_name, //$config->get('screen_name'),
      '#attached' => [
        'library' => ['twitter_sync/widgets'],
      ],
    ];
  }

}
